import re
from django.conf import settings

class DomainMiddleware(object):
    def process_request(self, request):
        url_config = getattr(settings, 'URL_CONFIG', None)
        if url_config:
            try:
                host = request.get_host()
                for (regex, value) in url_config:
                    if re.search(regex, host):
                        request.urlconf = value
                        break
            except Exception, e:
                print str(e)
                pass


from setuptools import setup
from codecs import open
from os import path

BASE = path.abspath(path.dirname(__file__))

with open(path.join(BASE, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='django-multidomain',
    version='1.1.4',
    url='https://github.com/cyacarinic/django-multidomain',
    author='Claudio Yacarini',
    author_email='cyacarinic@gmail.com',
    description='Django application, set urls per domain.',
    packages=[
        'multidomain',
    ],
    include_package_data=True,
    long_description = long_description,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Internet :: WWW/HTTP :: WSGI',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    keywords='django url domain host multi',
)

